@@ -41,7 +41,7 @@ class MetaMax extends CMSModule
 
   function GetVersion()
   {
-    return '1.7.9.1';
+    return '1.8';
   }
 
   function GetHelp()
@@ -91,8 +91,7 @@ class MetaMax extends CMSModule
 
   function GetDashboardOutput() 
   {
-	global $gCms;
-	$db = &$gCms->GetDb();
+	$db = cmsms()->GetDb();
 
 	$rcount = $db->GetOne('select count(*) from '.cms_db_prefix().'module_metamax');
 	
