@@ -47,7 +47,7 @@ $pageSmarty = $this->GetPreference('page_smarty','');
 
 ///// PAGE SPECIFIC METADATA /////
 
-if (is_object($page_meta) && $page_meta->Metadata() != '') {
+if (is_object($page_meta) && $page_meta->Metadata() != '' && $page_meta->Metadata() != '{* Add code here that should appear in the metadata section of all new pages *}') {
     $pageMeta = "\n" . $page_meta->Metadata();
 }
 
